<?php
/*
Plugin Name: Woocommerce custom tshirt designer (shared on wplocker.com)
Plugin URI: http://www.solvercircle.com
Description:This plugin is used to design or customize t-shirts by users.  
Version: 2.0.3
Author: SolverCircle
Author URI: http://www.solvercircle.com
*/

if(!defined( 'ABSPATH' )) exit;
define( 'WTD_URL', plugins_url('',__FILE__) );
define( 'WTD_DIR_PATH', plugin_dir_path( __FILE__ ) );

include ( 'includes/tshirt-designer-setup.php' );
include ( 'includes/tshirt-designer-button-display.php' );
include ( 'includes/tshirt-designer-admin-art.php' );
include ( 'includes/tshirt-designer-settings.php' );
include ( 'includes/tshirt-woocp.php' );
include ( 'includes/zipArchive.php' );
    
function wtd_metabox() 
{
  add_meta_box( 'wtd_metabox_custom','Custom Design Option','wtd_design_option_content','product', 'normal', 'high' );
}
add_action( 'admin_init', 'wtd_metabox' );
   
function wtd_design_option_content( $product )
{
  $custom =                  get_post_custom( $product->ID );
  if(isset($custom[ "_wtd_custom_design_checkbox" ][0]))
  {
    $meta_box_check =          $custom[ "_wtd_custom_design_checkbox" ][0];
  }
  else
  {
    $meta_box_check = FALSE;
  }
  $custom_price =            esc_html( get_post_meta( $product->ID,'_wtd_custom_design_extra_price', true ) );
  $custom_back_side_img =    esc_html( get_post_meta( $product->ID,'_wtd_custom_back_image', true ) );
  $upload_base_url =         wtd_get_upload_dir();
?>
  <table id="wtd_custom_meta">
    <tr>
      <td>Enable design panel at frontend?</td>
      <td><input type="checkbox" name="wtd_enable_checkbox" id="wtd_enable_checkbox"  <?php if( $meta_box_check == true ) { ?>checked="checked"<?php } ?>/></td>
    </tr>
    <tr>
      <td>Extra price for custom design</td>
      <td><input type="number" name="wtd_extra_price" id="wtd_extra_price" value="<?php echo $custom_price;?>" /></td>
    </tr>
    <tr>
      <td>Upload back side image</td> 
      <td>
        <input type="text" readonly="true" name="wtd_back_side_image_url" id="wtd_back_side_image_url"/>  
        <span><input id="wtd_back_side_image_uploader" class="button-primary" name="wtd_back_side_image_uploader" type="button" value="Browse"/></span>
      </td>
    <?php if( $custom_back_side_img ){?>
        <td><img src="<?php echo $upload_base_url['baseurl'].$custom_back_side_img;?>"/></td>
    <?php }?>
    </tr>
  </table>
<?php
}
	
add_action( 'save_post','wtd_custom_meta_save', 10, 2 );

function wtd_custom_meta_save( $post_id,$product ) 
{
  if ( $product->post_type == 'product' ) 
  {
    $get_back_side_image =  esc_html( get_post_meta( $post_id,'_wtd_custom_back_image', true ) );
    
    if( isset($_POST['wtd_extra_price']) && $_POST['wtd_extra_price'] )
    {
      update_post_meta( $post_id, '_wtd_custom_design_extra_price', $_POST['wtd_extra_price'] );
    }
    else
    {
      update_post_meta( $post_id, '_wtd_custom_design_extra_price', '' );
    }
    
    if( isset($_POST["wtd_enable_checkbox"]) && $_POST["wtd_enable_checkbox"] )
    {
      update_post_meta( $post_id, '_wtd_custom_design_checkbox', $_POST["wtd_enable_checkbox"] );
    }
    else
    {
      update_post_meta( $post_id, '_wtd_custom_design_checkbox', '');
    }
     
    if(isset($_POST["wtd_back_side_image_url"]) && $_POST["wtd_back_side_image_url"])
    {
      $get_url = $_POST['wtd_back_side_image_url'];
      $upload_base_url = wtd_get_upload_dir();
      $img_url = str_replace( $upload_base_url['baseurl'],'',$get_url );
      update_post_meta( $post_id,  '_wtd_custom_back_image',$img_url );
    }
    else
    {
      update_post_meta( $post_id,  '_wtd_custom_back_image',$get_back_side_image );
    }
  }
}
    
function wtd_assets_load()
{
  wp_enqueue_script( 'jquery');
  wp_enqueue_style(  'wtd-custom-style',plugins_url( '/css/wtd.css', __FILE__  ) );
  wp_enqueue_script( 'wtd-custom-js', plugins_url( '/js/wtd.js', __FILE__  ) );
  wp_enqueue_script( 'wtd-fabric-js-1.2.0', 'http://cdnjs.cloudflare.com/ajax/libs/fabric.js/1.2.0/fabric.all.min.js',array(),'1.2.0',true);
  wp_enqueue_script( 'wtd-upload-form', plugins_url( '/js/jquery.form.js', __FILE__  ) );
  wp_enqueue_script( 'wtd-colorpicker-js', plugins_url( '/js/colorpicker/jscolor.js', __FILE__ ));
  
  if( !session_id() )
  {
    session_start();
  }
}
        
function wtd_add_custom_price( $cart_object ) 
{
  foreach ( $cart_object->cart_contents as $key => $value )
  {
    if( isset( $value['variation']['wtd_type'] ) )
    {
      if( isset( $value['variation']['wtd_custom_price'] ))
      {
        $value['data']->price = $value['variation']['wtd_custom_price'];
      }
    }
  }
}

function wtd_remove_custom_data( $meta_value )
{
  return array(
       '_qty',
       '_tax_class',
       '_product_id',
       '_variation_id',
       '_line_subtotal',
       '_line_subtotal_tax',
       '_line_total',
       '_line_tax',
       'design',
       'wtd_type',
       'wtd_custom_price',
       'wtd_custom_logo',
       'wtd_custom_design', 
      );
}

function wtd_add_hidden_field()
{
  echo '<div class="wtd_admin_custom_design_main_div">';
  echo '<div class="wtd_admin_custom_design_close_icon"></div>';
  echo '<div class="wtd_admin_custom_design_image_content"></div>';
  echo '</div>';
  echo '<div class="wtd_overlay"></div>';
  echo '<input type="hidden" name="wtd_admin" id="wtd_admin" value="'. WTD_URL .'"/>';
}

add_action( 'woocommerce_hidden_order_itemmeta','wtd_remove_custom_data' );
add_action( 'woocommerce_before_calculate_totals', 'wtd_add_custom_price' );
add_action( 'init','wtd_assets_load' );
add_action( 'woocommerce_after_shop_loop_item','wtd_button_view_on_products_page' );
add_action( 'wp_footer','wtd_button_display' );
add_action( 'woocommerce_after_add_to_cart_button','wtd_button_view_on_details_page' );
add_action( 'admin_footer','wtd_add_hidden_field');
register_activation_hook( __FILE__, 'wtd_plugin_install' );
register_deactivation_hook(__FILE__, 'wtd_plugin_uninstall');
?>